Files
json/include/nlohmann
Niels Lohmann ddb5d366e7 Look up the key only once in the callback parser's key()
Since #5466, key() searched the object for a duplicate key and then looked
the key up again to insert the placeholder. Use a single emplace() instead.
Parsing a 32k-member object with a callback: 10.4 ms -> 7.2 ms (3.12.0: 8.0 ms).

Signed-off-by: Niels Lohmann <mail@nlohmann.me>
2026-10-14 20:20:59 +02:00
..
2026-01-01 20:00:39 +01:00
2026-01-01 20:00:39 +01:00